@@ -783,8 +783,8 @@ int main(int argc, char **argv)
 	      if (qs[i]->calls == 0)
 		{
 		  char buf1[512], buf2[512];
-		  snprintf(buf1, 512, "fgrep -q %s xen.h", qs[i]->name);
-		  snprintf(buf2, 512, "fgrep -q %s s7.html", qs[i]->name);
+		  snprintf(buf1, 512, "grep -F -q %s xen.h", qs[i]->name);
+		  snprintf(buf2, 512, "grep -F -q %s s7.html", qs[i]->name);
 		  if (system((const char *)buf1) == 0) 
 		    {
 		      if (system((const char *)buf2) == 0) 
@@ -887,8 +887,8 @@ int main(int argc, char **argv)
 	      if (ffitest_case)
 		{
 		  char buf1[512], buf2[512];
-		  snprintf(buf1, 512, "fgrep -q %s xen.h", qs[i]->name);
-		  snprintf(buf2, 512, "fgrep -q %s s7.html", qs[i]->name);
+		  snprintf(buf1, 512, "grep -F -q %s xen.h", qs[i]->name);
+		  snprintf(buf2, 512, "grep -F -q %s s7.html", qs[i]->name);
 		  if ((system((const char *)buf1) != 0) &&
 		      (system((const char *)buf2) != 0))
 		    fprintf(FD, "\njust ffitest!");
