@@ -10,15 +10,17 @@
  */
 
 #define XEN_MAJOR_VERSION 4
-#define XEN_MINOR_VERSION 2
-#define XEN_VERSION "4.2"
+#define XEN_MINOR_VERSION 3
+#define XEN_VERSION "4.3"
 
 /* HISTORY:
  *
+ *  3-May-23:  clm_complex_i: we want a double here not the float _Complex_I
+ *  --------
  *  10-Apr:    s7_apply_*.
  *  16-Mar:    more changes for s7_apply_*.
  *  8-Mar-22:  moved s7_apply_* here from s7.h.
- * --------
+ *  --------
  *  14-May-20: g++ xen.h|c changes for Ruby 2.7 and gcc version 10.
  *  --------
  *  26-Apr-18: changed XEN_MAKE_OBJECT_TYPE in s7 again...
@@ -1117,7 +1119,12 @@ extern size_t xen_s7_number_location, xen_s7_denominator_location;
 #if HAVE_COMPLEX_NUMBERS
   #define XEN_HAVE_COMPLEX_NUMBERS                 1
   #define XEN_COMPLEX_P(Arg)                       s7_is_complex(Arg)
-  #define XEN_TO_C_COMPLEX(a)                      (s7_real_part(a) + s7_imag_part(a) * _Complex_I)
+  #if (defined(__GNUC__))
+    #define clm_complex_i 1.0i
+  #else
+    #define clm_complex_i _Complex_I
+  #endif
+  #define XEN_TO_C_COMPLEX(a)                      (s7_real_part(a) + s7_imag_part(a) * clm_complex_i)
   #define C_TO_XEN_COMPLEX(a)                      s7_make_complex(s7, creal(a), cimag(a))
 #else
   #define XEN_HAVE_COMPLEX_NUMBERS                 0
